@@ -1,5 +1,5 @@
 #!/bin/bash
-# $Id: build.sh 6247 2016-01-25 17:39:06Z flaterco $
+# $Id: build.sh 6280 2016-02-23 00:33:39Z flaterco $
 # Sample script for cross-compiling libpng, libtcd, libxtide, tide, and xttpd
 # for Android on x86 Linux.  Review and edit before use.
 
@@ -49,7 +49,7 @@ fi
 LIBPNG=libpng-1.6.21
 LIBTCD=libtcd-2.2.7-r2
 LIBTCDDIR=libtcd-2.2.7
-XTIDE=xtide-2.15
+XTIDE=xtide-2.15.1
 
 # Edit as needed.
 NDKPATH=/usr/local/android-ndk-r10e
