@@ -1,4 +1,4 @@
-// $Id: tide.cc 5059 2013-07-21 12:41:26Z flaterco $
+// $Id: tide.cc 5749 2014-10-11 19:42:10Z flaterco $
 
 /*  tide  Command-line client for dusty old TTYs and line printers.
 
@@ -18,7 +18,8 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "common.hh"
+#include "libxtide/libxtide.hh"
+using namespace libxtide;
 
 
 // Separator between tide stations in text client output
