@@ -1,4 +1,4 @@
-// $Id: wvsrtv.cc 3956 2011-07-31 01:12:17Z flaterco $
+// $Id: wvsrtv.cc 5749 2014-10-11 19:42:10Z flaterco $
 
 /*  wvsrtv  Retrieve WVS data from compressed files.
 
@@ -534,7 +534,6 @@ static void build_seg (float dlat, float dlon, int *cont, int *nsegs,
 *                                                                           *
 \***************************************************************************/
 
-namespace Global {
 int wvsrtv (char const * const file,
             char const * const dir,
             int latd,
@@ -950,6 +949,3 @@ int wvsrtv (char const * const file,
 
     return (nsegs);
 }
-}
-
-// Cleanup2006 Cruft ThirdPartyCode WontFix
