@@ -1,4 +1,4 @@
-// $Id: xtide.cc 5040 2013-07-10 01:38:13Z flaterco $
+// $Id: xtide.cc 5749 2014-10-11 19:42:10Z flaterco $
 
 /*  XTide  Harmonic tide clock and tide predictor.
 
@@ -28,7 +28,7 @@ int main (int argc, char **argv) {
   Global::initializeGraphFont();
   #endif
   Global::initTerm();
-  Global::root = new xxRoot (argc, argv);
-  Global::root->run();
+  xxroot = new xxRoot (argc, argv);
+  xxroot->run();
   exit (0);
 }
