@@ -1,4 +1,4 @@
-// $Id: xttpd.cc 6225 2016-01-23 13:26:42Z flaterco $
+// $Id: xttpd.cc 6280 2016-02-23 00:33:39Z flaterco $
 
 /*  xttpd  XTide web server.
 
@@ -258,7 +258,19 @@ static void setupSocket (sockaddr_storage &addr,
       Global::xperror ("setsockopt");
     }
   }
-  bool bound = (bind(s,(sockaddr *)&addr,sizeof(addr))==0);
+
+  // 2016-02-21
+  // Manfred Antar reported "bind: Invalid argument" occurring on FreeBSD and
+  // OS X as a regression from 2.14.  The FreeBSD man page for bind states
+  // that EINVAL can be raised if "the addrlen argument is not a valid length
+  // for the address family."  Apparently, we have to fake the size to match
+  // the applicable narrowed type, rather than passing the true size of
+  // sockaddr_storage.  The error does not occur with linux libc.
+  const socklen_t addrlen (addr.ss_family==AF_INET6 ? sizeof(sockaddr_in6)
+                                                    : sizeof(sockaddr_in));
+  assert (addrlen <= sizeof(addr));
+
+  bool bound = (bind(s,(sockaddr *)&addr,addrlen)==0);
   int yerrno = errno;
   if (!bound && addr.ss_family == AF_INET6) {
 
@@ -288,7 +300,7 @@ static void setupSocket (sockaddr_storage &addr,
 
     for (unsigned magic=4; !bound && magic>0; --magic) {
       ((sockaddr_in6 *)&addr)->sin6_scope_id = magic;
-      bound = (bind(s,(sockaddr *)&addr,sizeof(addr))==0);
+      bound = (bind(s,(sockaddr *)&addr,addrlen)==0);
     }
   }
   // Report the error from the first failure so that it won't be obscured by
