@@ -1,4 +1,4 @@
-// $Id: xxClock.cc 5034 2013-07-08 01:58:13Z flaterco $
+// $Id: xxClock.cc 5749 2014-10-11 19:42:10Z flaterco $
 
 /*  xxClock  Tide clock.
 
@@ -19,10 +19,10 @@
 */
 
 #include "xtide.hh"
-#include "Graph.hh"
-#include "PixelatedGraph.hh"
-#include "RGBGraph.hh"
-#include "SVGGraph.hh"
+#include "libxtide/Graph.hh"
+#include "libxtide/PixelatedGraph.hh"
+#include "libxtide/RGBGraph.hh"
+#include "libxtide/SVGGraph.hh"
 #include "xxPixmapGraph.hh"
 #include "xxHorizDialog.hh"
 #include "xxMultiChoice.hh"
@@ -84,7 +84,7 @@ The options menu supplies the following commands:\n\
   selecting a new location.\n\
 \n\
   Control Panel:  Advanced XTide configuration.");
-  (void) Global::root->newHelpBox (helpstring);
+  (void) xxroot->newHelpBox (helpstring);
 }
 
 
@@ -183,7 +183,7 @@ void xxClock::toggleButtons() {
   default:
     assert (0);
   }
-  Global::root->newClock (_station.release(), bs);
+  xxroot->newClock (_station.release(), bs);
 }
 
 
