@@ -1,4 +1,4 @@
-// $Id: xxDisclaimer.cc 4501 2012-05-27 17:41:58Z flaterco $
+// $Id: xxDisclaimer.cc 5036 2013-07-08 23:15:35Z flaterco $
 
 /*  xxDisclaimer  Annoy the user.
 
@@ -24,13 +24,13 @@
 
 static const unsigned disclaimerTextHeight (500U);
 
-static constString disclaimer = "\
+static constString disclaimer = "This is " XTideVersionString "\n\n\
 NOTE.  The license and disclaimer appearing below applies to the XTide\n\
 program itself.  For information about permissions on the harmonic\n\
 constants, please read the relevant disclaimers provided by the\n\
 maintainer of those constants.\n\
 \n\
-             XTide   Copyright (C) 1998 David Flater.\n\
+            XTide 2   Copyright (C) 1998 David Flater.\n\
 \n\
 This software is provided under the terms of the GNU General Public\n\
 License, either version 3 of the License, or (at your option) any later\n\
@@ -749,15 +749,16 @@ static void disclaimerdismissCallback (Widget w unusedParameter,
 xxWindow * const xxDisclaimer::dismiss() {
   Boolean tstate;
   Arg targs[1] = {{(char*)XtNstate, (XtArgVal)&tstate}};
-  assert (dontShowButton.get());
-  XtGetValues (dontShowButton->widget(), targs, 1);
-  if (tstate)
-    Global::disableDisclaimer();
+  if (dontShowButton.get()) {
+    XtGetValues (dontShowButton->widget(), targs, 1);
+    if (tstate)
+      Global::disableDisclaimer();
+  }
   return this;
 }
 
 
-xxDisclaimer::xxDisclaimer (const xxWidget &shell):
+xxDisclaimer::xxDisclaimer (const xxWidget &shell, bool enableDisableButton):
   xxWindow (shell, formContainer) {
 
   setTitle ("Disclaimer");
@@ -807,27 +808,35 @@ xxDisclaimer::xxDisclaimer (const xxWidget &shell):
     {(char*)XtNbottom, (XtArgVal)XawChainBottom}
   };
 
-  Widget dontShowButtonWidget = xxX::createXtWidget (
-    "Don't show this again", toggleWidgetClass, container->widget(),
-    button1Args, 7);
-  dontShowButton = xxX::wrap (dontShowButtonWidget);
+  if (!enableDisableButton) {
+    Widget dismissButtonWidget = xxX::createXtWidget ("Dismiss",
+      commandWidgetClass, container->widget(), button1Args, 7);
+    XtAddCallback (dismissButtonWidget, XtNcallback, disclaimerdismissCallback,
+      (XtPointer)this);
+    dismissButton = xxX::wrap (dismissButtonWidget);
+  } else {
+    Widget dontShowButtonWidget = xxX::createXtWidget (
+      "Don't show this again", toggleWidgetClass, container->widget(),
+      button1Args, 7);
+    dontShowButton = xxX::wrap (dontShowButtonWidget);
 
-  Arg button2Args[8] =  {
-    {XtNbackground, (XtArgVal)xxX::pixels[Colors::button]},
-    {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]},
-    {(char*)XtNfromVert, (XtArgVal)viewportWidget},
-    {(char*)XtNfromHoriz, (XtArgVal)dontShowButtonWidget},
-    {(char*)XtNleft, (XtArgVal)XawChainLeft},
-    {(char*)XtNright, (XtArgVal)XawChainLeft},
-    {(char*)XtNtop, (XtArgVal)XawChainBottom},
-    {(char*)XtNbottom, (XtArgVal)XawChainBottom}
-  };
+    Arg button2Args[8] =  {
+      {XtNbackground, (XtArgVal)xxX::pixels[Colors::button]},
+      {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]},
+      {(char*)XtNfromVert, (XtArgVal)viewportWidget},
+      {(char*)XtNfromHoriz, (XtArgVal)dontShowButtonWidget},
+      {(char*)XtNleft, (XtArgVal)XawChainLeft},
+      {(char*)XtNright, (XtArgVal)XawChainLeft},
+      {(char*)XtNtop, (XtArgVal)XawChainBottom},
+      {(char*)XtNbottom, (XtArgVal)XawChainBottom}
+    };
 
-  Widget dismissButtonWidget = xxX::createXtWidget ("Dismiss",
-    commandWidgetClass, container->widget(), button2Args, 8);
-  XtAddCallback (dismissButtonWidget, XtNcallback, disclaimerdismissCallback,
-    (XtPointer)this);
-  dismissButton = xxX::wrap (dismissButtonWidget);
+    Widget dismissButtonWidget = xxX::createXtWidget ("Dismiss",
+      commandWidgetClass, container->widget(), button2Args, 8);
+    XtAddCallback (dismissButtonWidget, XtNcallback, disclaimerdismissCallback,
+      (XtPointer)this);
+    dismissButton = xxX::wrap (dismissButtonWidget);
+  }
 
   obeyMouseWheel (popup->widget());
   obeyMouseWheel (scrollbarWidget);
@@ -849,8 +858,8 @@ void xxDisclaimer::globalRedraw() {
   };
   assert (dismissButton.get());
   XtSetValues (dismissButton->widget(), buttonArgs, 2);
-  assert (dontShowButton.get());
-  XtSetValues (dontShowButton->widget(), buttonArgs, 2);
+  if (dontShowButton.get())
+    XtSetValues (dontShowButton->widget(), buttonArgs, 2);
   Arg args[2] =  {
     {XtNbackground, (XtArgVal)xxX::pixels[Colors::background]},
     {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]}
