@@ -1,4 +1,4 @@
-// $Id: xxErrorBox.cc 2641 2007-09-02 21:31:02Z flaterco $
+// $Id: xxErrorBox.cc 4497 2012-05-27 00:33:09Z flaterco $
 
 /*  xxErrorBox  Show error message.
 
@@ -73,10 +73,10 @@ xxErrorBox::xxErrorBox (const xxWidget &shell,
       {XtNinternalHeight, (XtArgVal)0},
       {XtNinternalWidth, (XtArgVal)0}
     };
-    XtCreateManagedWidget ("", labelWidgetClass, container->widget(), args, 5);
+    xxX::createXtWidget ("", labelWidgetClass, container->widget(), args, 5);
   }
 
-  Widget labelWidget = XtCreateManagedWidget (errorMessage.aschar(),
+  Widget labelWidget = xxX::createXtWidget (errorMessage.aschar(),
     labelWidgetClass, container->widget(), backgroundArgs, 2);
   label = xxX::wrap (labelWidget);
 
@@ -91,7 +91,7 @@ xxErrorBox::xxErrorBox (const xxWidget &shell,
       buttonLabel = "Exit";
     else
       buttonLabel = "Oops";
-    Widget buttonWidget = XtCreateManagedWidget (buttonLabel,
+    Widget buttonWidget = xxX::createXtWidget (buttonLabel,
       commandWidgetClass, container->widget(), buttonArgs, 2);
     XtAddCallback (buttonWidget, XtNcallback, dieCallback, (XtPointer)this);
     button = xxX::wrap (buttonWidget);
