@@ -1,4 +1,4 @@
-// $Id: xxGlobal.cc 4018 2011-08-28 14:37:32Z flaterco $	
+// $Id: xxGlobal.cc 5749 2014-10-11 19:42:10Z flaterco $	
 
 /*  xxGlobal  xx additions to Global.
 
@@ -24,25 +24,23 @@
 #include <gps.h>
 #endif
 
-xxRoot *Global::root;
-
-const Dstr &getXtideConf (unsigned lineNo); // in Global.cc
+xxRoot *xxroot;
 
 
-constString Global::WVSdir() {
+constString WVSdir() {
   static bool firstCall (true);
   static Dstr wvs_dir;
   if (firstCall) {
     firstCall = false;
     wvs_dir = getenv ("WVS_DIR");
     if (wvs_dir.isNull())
-      wvs_dir = getXtideConf(1U);
+      wvs_dir = Global::getXtideConf(1U);
   }
   return wvs_dir.aschar();
 }
 
 
-void Global::PositioningSystem (Coordinates &currentPosition) {
+void PositioningSystem (Coordinates &currentPosition) {
   currentPosition.makeNull();
 
 #ifdef GPS_GOOD
@@ -91,5 +89,3 @@ void Global::PositioningSystem (Coordinates &currentPosition) {
   }
 #endif
 }
-
-// Cleanup2006 Done
