@@ -1,4 +1,4 @@
-// $Id: xxGlobe.cc 4497 2012-05-27 00:33:09Z flaterco $
+// $Id: xxGlobe.cc 5749 2014-10-11 19:42:10Z flaterco $
 
 /*  xxGlobe   Location chooser using Orthographic Projection.
 
@@ -225,8 +225,8 @@ void xxGlobe::drawCoastlines () {
     for (lon = startlon ; lon < endlon ; ++lon) {
       int k, nseg, offset(0);
 
-      nseg = Global::wvsrtv (files[coast], Global::WVSdir(), lat, lon,
-                             &latray, &lonray, &segray);
+      nseg = wvsrtv (files[coast], WVSdir(), lat, lon,
+		     &latray, &lonray, &segray);
 
       if (nseg) {
         for (k = 0 ; k < nseg ; ++k) {
@@ -266,7 +266,7 @@ void xxGlobe::drawCoastlines () {
       }
     }
   }
-  Global::wvsrtv ("clean", NULL, 0, 0, &latray, &lonray, &segray);
+  wvsrtv ("clean", NULL, 0, 0, &latray, &lonray, &segray);
 }
 
 
@@ -578,7 +578,7 @@ static void xxGlobeFlatCallback (Widget w unusedParameter,
                                  XtPointer client_data,
                                  XtPointer call_data unusedParameter) {
   assert (client_data);
-  Global::root->newMap ();
+  xxroot->newMap ();
   delete ((xxGlobe *)client_data)->dismiss();
 }
 
@@ -623,7 +623,7 @@ Buttons in the globe window:\n\
 Keyboard:\n\
 \n\
   Arrow keys:  rotate North/South/East/West.");
-  (void) Global::root->newHelpBox (helpstring);
+  (void) xxroot->newHelpBox (helpstring);
 }
 
 
@@ -803,7 +803,7 @@ void xxGlobe::mouseButton (const XButtonEvent *xbe) {
       }
     }
     if (closestsr)
-      Global::root->newGraph (*closestsr);
+      xxroot->newGraph (*closestsr);
   }
 }
 
@@ -906,7 +906,7 @@ xxGlobe::xxGlobe (const xxWidget &shell):
   realize();
   fixSize();
 
-  Global::PositioningSystem (currentPosition);
+  PositioningSystem (currentPosition);
   if (currentPosition.isNull()) {
     const Configurable &gl = Global::settings["gl"];
     if (gl.isNull || gl.d == 360.0)
