@@ -1,4 +1,4 @@
-// $Id: xxGraphMode.cc 5034 2013-07-08 01:58:13Z flaterco $
+// $Id: xxGraphMode.cc 5749 2014-10-11 19:42:10Z flaterco $
 
 /*  xxGraphMode  Tide graphs in a window.
 
@@ -19,10 +19,10 @@
 */
 
 #include "xtide.hh"
-#include "Graph.hh"
-#include "PixelatedGraph.hh"
-#include "RGBGraph.hh"
-#include "SVGGraph.hh"
+#include "libxtide/Graph.hh"
+#include "libxtide/PixelatedGraph.hh"
+#include "libxtide/RGBGraph.hh"
+#include "libxtide/SVGGraph.hh"
 #include "xxPixmapGraph.hh"
 #include "xxGraphMode.hh"
 #include "xxHorizDialog.hh"
@@ -85,7 +85,7 @@ The options menu supplies the following commands:\n\
   selecting a new location.\n\
 \n\
   Control Panel:  Advanced XTide configuration.");
-  (void) Global::root->newHelpBox (helpstring);
+  (void) xxroot->newHelpBox (helpstring);
 }
 
 
