@@ -1,4 +1,4 @@
-// $Id: xxMap.cc 4497 2012-05-27 00:33:09Z flaterco $
+// $Id: xxMap.cc 5749 2014-10-11 19:42:10Z flaterco $
 
 /*  xxMap   Location chooser using Cylindrical Equidistant projection.
 
@@ -250,8 +250,8 @@ void xxMap::redrawMap () {
       for (lon = startlon ; lon < endlon ; ++lon) {
         int k, nseg, offset(0);
 
-        nseg = Global::wvsrtv (files[coast], Global::WVSdir(), lat, lon,
-                               &latray, &lonray, &segray);
+        nseg = wvsrtv (files[coast], WVSdir(), lat, lon,
+		       &latray, &lonray, &segray);
 
         if (nseg) {
           /*  Get rid of single point islands that were required for
@@ -286,7 +286,7 @@ void xxMap::redrawMap () {
         }
       }
     }
-    Global::wvsrtv ("clean", NULL, 0, 0, &latray, &lonray, &segray);
+    wvsrtv ("clean", NULL, 0, 0, &latray, &lonray, &segray);
   } else
     XCopyArea (xxX::display, topPixmap, mapPixmap, xxX::markGC,
                0, 0, x_map_size, y_map_size, 0, 0);
@@ -379,7 +379,7 @@ static void xxMapRoundCallback (Widget w unusedParameter,
                                 XtPointer client_data,
                                 XtPointer call_data unusedParameter) {
   assert (client_data);
-  Global::root->newGlobe();
+  xxroot->newGlobe();
   delete ((xxMap *)client_data)->dismiss();
 }
 
@@ -424,7 +424,7 @@ Buttons in the map window:\n\
 Keyboard:\n\
 \n\
   Arrow keys:  pan up/down/left/right.");
-  (void) Global::root->newHelpBox (helpstring);
+  (void) xxroot->newHelpBox (helpstring);
 }
 
 
@@ -695,7 +695,7 @@ void xxMap::mouseButton (const XButtonEvent *xbe) {
       }
     }
     if (closestsr)
-      Global::root->newGraph (*closestsr);
+      xxroot->newGraph (*closestsr);
   }
 }
 
@@ -819,7 +819,7 @@ xxMap::xxMap (const xxWidget &shell):
   redrawZeroLevel = true;
   redrawMap();
 
-  Global::PositioningSystem (currentPosition);
+  PositioningSystem (currentPosition);
   if (!currentPosition.isNull()) {
     // Got a GPS fix; start zoomed in on current location.
     while (zoomLevel < maxZoomLevel)
