@@ -1,4 +1,4 @@
-// $Id: xxRareModeSavePrompts.cc 2641 2007-09-02 21:31:02Z flaterco $
+// $Id: xxRareModeSavePrompts.cc 4497 2012-05-27 00:33:09Z flaterco $
 
 /*  xxRareModeSavePrompts  Get a file name and two timestamps from the
     user.  If successful, do caller.save (filename, startTime, endTime).
@@ -124,7 +124,7 @@ The active time zone is ");
     else
       helptext += "UTC0";
     helptext += ".";
-    Widget labelWidget = XtCreateManagedWidget (helptext.aschar(),
+    Widget labelWidget = xxX::createXtWidget (helptext.aschar(),
       labelWidgetClass, container->widget(), labelArgs, 3);
     helpLabel = xxX::wrap (labelWidget);
   }
@@ -145,17 +145,17 @@ The active time zone is ");
 							           _timezone));
 
   {
-    Widget labelWidget = XtCreateManagedWidget ("  ", labelWidgetClass,
+    Widget labelWidget = xxX::createXtWidget ("  ", labelWidgetClass,
       container->widget(), labelArgs, 3);
     spaceLabel = xxX::wrap (labelWidget);
   }{
-    Widget buttonWidget = XtCreateManagedWidget ("Go", commandWidgetClass,
+    Widget buttonWidget = xxX::createXtWidget ("Go", commandWidgetClass,
       container->widget(), buttonArgs, 4);
     XtAddCallback (buttonWidget, XtNcallback, xxRareModeSavePromptsCallback,
      (XtPointer)this);
     goButton = xxX::wrap (buttonWidget);
   }{
-    Widget buttonWidget = XtCreateManagedWidget ("Cancel", commandWidgetClass,
+    Widget buttonWidget = xxX::createXtWidget ("Cancel", commandWidgetClass,
       container->widget(), buttonArgs, 4);
     XtAddCallback (buttonWidget, XtNcallback,
       xxRareModeSavePromptsCancelCallback, (XtPointer)this);
