@@ -1,4 +1,4 @@
-// $Id: xxRoot.cc 5036 2013-07-08 23:15:35Z flaterco $
+// $Id: xxRoot.cc 5749 2014-10-11 19:42:10Z flaterco $
 
 /*  xxRoot  XTide "root" window (control panel, top-level logic)
 
@@ -41,21 +41,21 @@ static const unsigned windowDressingWidth (32U);
 
 
 static void errorCallback (const Dstr &errorMessage, Error::ErrType fatality) {
-  Global::root->newErrorBox (errorMessage, fatality);
+  xxroot->newErrorBox (errorMessage, fatality);
 }
 
 
 static void dismissCallback (Widget w unusedParameter,
                              XtPointer client_data unusedParameter,
                              XtPointer call_data unusedParameter) {
-  Global::root->unrealize();
+  xxroot->unrealize();
 }
 
 
 static void applyCallback (Widget w unusedParameter,
                            XtPointer client_data unusedParameter,
                            XtPointer call_data unusedParameter) {
-  Global::root->apply (xxRoot::justApply);
+  xxroot->apply (xxRoot::justApply);
 }
 
 
@@ -268,7 +268,7 @@ void xxRoot::apply (ApplyProtocol protocol) {
 static void saveCallback (Widget w unusedParameter,
                           XtPointer client_data unusedParameter,
                           XtPointer call_data unusedParameter) {
-  Global::root->apply (xxRoot::applyAndSave);
+  xxroot->apply (xxRoot::applyAndSave);
 }
 
 
@@ -315,7 +315,7 @@ how these formats work.  Here is how to get XTide to use 24-hour time instead\n\
 of AM/PM:\n\
    Hour format  %H\n\
    Time format  %H:%M %Z");
-  (void) Global::root->newHelpBox (helpstring);
+  (void) xxroot->newHelpBox (helpstring);
 }
 
 
