@@ -1,4 +1,4 @@
-// $Id: xxX.cc 5749 2014-10-11 19:42:10Z flaterco $
+// $Id: xxX.cc 6199 2016-01-14 23:39:45Z flaterco $
 
 /*  xxX  Globals for interfacing with X11.
 
@@ -30,7 +30,6 @@
 #undef   include
 #endif
 
-
 const unsigned xxX::minWidthFudgeFactor (15U);
 
 // We've had good luck with 48; that's what the CDE demanded.  If 48
@@ -72,6 +71,9 @@ Pixmap xxX::iconPixmap;
 
 
 static Colormap iconColormap=0;
+#ifdef HAVE_XAW3DXFT
+static Xaw3dXftData *xaw3dxft_data=NULL;
+#endif
 
 
 // These are only valid if !displaySucks.  They do NOT correspond
@@ -550,15 +552,17 @@ const Widget xxX::connect (int &argc, char **argv) {
   require (putenv (env_string) == 0);
 
   #ifdef HAVE_XAW3DXFT
-    Xaw3dXftEncoding = 8;        // Encoding is Latin-1, not UTF-8.
-    Xaw3dXftMenuSpacing = 0;     // Get rid of extra vertical spacing in menus.
-    Xaw3dXftMultiColumnMenu = 1; // Make Set Time dialog not suck.
-    Xaw3dXftNoHilitReverse = 1;  // Required for Xaw3dXftMultiColumnMenu.
+    GET_XAW3DXFT_DATA(xaw3dxft_data);
+    assert (xaw3dxft_data);
+    xaw3dxft_data->encoding = 8;          // Encoding is Latin-1, not UTF-8.
+    xaw3dxft_data->menu_spacing = 0;      // Get rid of extra vertical spacing in menus.
+    xaw3dxft_data->multi_column_menu = 1; // Make Set Time dialog not suck.
+    xaw3dxft_data->no_hilit_reverse = 1;  // Required for Xaw3dXftMultiColumnMenu.
 
     // Tweaks recommended by J.-P.
-    // Xaw3dXftButtonDashed = 1; // Make button mouse-over harder to see.
-    Xaw3dXftSetInsensitiveTwist((char*)"#a00000");
-    Xaw3dXftSetHilitColor((char*)"#332211");
+    // xaw3dxft_data->button_dashed = 1;  // Make button mouse-over harder to see.
+    xaw3dxft_data->proc->set_insensitive_twist((char*)"#a00000");
+    xaw3dxft_data->proc->set_hilit_color((char*)"#332211");
   #endif
 
   Widget widget;
@@ -745,14 +749,15 @@ void xxX::connectPostSettingsHook (Widget rootWidget) {
     // because libXaw3dxft has its own hard-coded default font.
 
     Configurable &cfbl = Global::settings["XX"];
+    assert (xaw3dxft_data);
     if (!cfbl.isNull) {
       constString defaultFontName = cfbl.s.aschar();
-      if (!(Xaw3dXftDefaultFont = getFont(defaultFontName)))
+      if (!(xaw3dxft_data->default_font = getFont(defaultFontName)))
 	Global::barf (Error::CANT_LOAD_FONT, defaultFontName);
-      defaultFontStruct = Xaw3dXftDefaultFont;
+      defaultFontStruct = xaw3dxft_data->default_font;
     } else {
       // Coerce DEFAULTFONT out of Xaw3dXft.c.
-      defaultFontStruct = Xaw3dXftGetFont (display, NULL);
+      defaultFontStruct = xaw3dxft_data->proc->get_font (display, NULL);
     }
   #else
     // The shell has no font attribute.  There is probably a better
